import { Construct } from "constructs";
import { FunctionInlineDefinition } from ".";
/**
 * SST Auth is a lightweight authentication solution for your applications. With a simple set of configuration you can deploy a function attached to your API that can handle various authentication flows.
 *
 * @example
 *
 * ```ts
 * import { Auth } from "@serverless-stack/resources"
 *
 * new Auth(stack, "auth", {
 *   api: myApi,
 *   function: "functions/auth.handler",
 *   prefix: "/auth" // optional
 * })
 */
export interface AuthProps {
    /**
     * The function that will handle authentication
     */
    function: FunctionInlineDefinition;
    /**
     * Optionally specify the prefix to mount authentication routes
     *
     * @default "/auth"
     */
    prefix?: string;
}
export declare class Auth extends Construct {
    constructor(scope: Construct, id: string, props: AuthProps);
}
